@@ -8,7 +8,7 @@
 #include "basictypes.h"
 #include "classifierlistitem.h"
 #include "codetextedit.h"
-#define DBG_SRC QLatin1String("ClassifierListPage")
+#define DBG_SRC QStringLiteral("ClassifierListPage")
 #include "debug_utils.h"
 #include "umldoc.h"
 #include "uml.h"  // only needed for log{Warn,Error}
@@ -23,13 +23,7 @@
 #include "entityattribute.h"
 #include "object_factory.h"
 
-#if QT_VERSION < 0x050000
-#include <kdialogbuttonbox.h>
-#endif
 #include <KLocalizedString>
-#if QT_VERSION < 0x050000
-#include <ktabwidget.h>
-#endif
 #include <ktextedit.h>
 
 #include <QApplication>
@@ -208,7 +202,6 @@ void ClassifierListPage::setupMoveButtons(QHBoxLayout* parentLayout)
  */
 void ClassifierListPage::setupActionButtons(const QString& itemType, QVBoxLayout* parentLayout)
 {
-#if QT_VERSION >= 0x050000
     QDialogButtonBox* buttonBox = new QDialogButtonBox(m_pItemListGB);
     m_pNewClassifierListItemButton = buttonBox->addButton(itemType, QDialogButtonBox::ActionRole);
     connect(m_pNewClassifierListItemButton, SIGNAL(clicked()), this, SLOT(slotNewListItem()));
@@ -216,14 +209,6 @@ void ClassifierListPage::setupActionButtons(const QString& itemType, QVBoxLayout
     connect(m_pDeleteListItemButton, SIGNAL(clicked()), this, SLOT(slotDelete()));
     m_pPropertiesButton = buttonBox->addButton(i18n("&Properties"), QDialogButtonBox::ActionRole);
     connect(m_pPropertiesButton, SIGNAL(clicked()), this, SLOT(slotProperties()));
-#else
-    KDialogButtonBox* buttonBox = new KDialogButtonBox(m_pItemListGB);
-    m_pNewClassifierListItemButton = buttonBox->addButton(itemType, KDialogButtonBox::ActionRole, this,
-                          SLOT(slotNewListItem()));
-    m_pDeleteListItemButton = buttonBox->addButton(i18n("&Delete"),
-                              KDialogButtonBox::ActionRole, this, SLOT(slotDelete()));
-    m_pPropertiesButton = buttonBox->addButton(i18n("&Properties"), KDialogButtonBox::ActionRole, this, SLOT(slotProperties()));
-#endif
     parentLayout->addWidget(buttonBox);
 }
 
@@ -240,11 +225,7 @@ void ClassifierListPage::setupDocumentationGroup(int margin)
     if (m_itemType == UMLObject::ot_Operation) {
         m_docTE = new KTextEdit();
         m_pCodeTE = new CodeTextEdit();
-#if QT_VERSION >= 0x050000
         QTabWidget* tabWidget = new QTabWidget();
-#else
-        KTabWidget* tabWidget = new KTabWidget();
-#endif
         tabWidget->addTab(m_docTE, i18n("Comment"));
         tabWidget->addTab(m_pCodeTE, i18n("Source Code"));
         docLayout->addWidget(tabWidget);
@@ -574,7 +555,7 @@ void ClassifierListPage::slotTopClicked()
     m_pItemListLB->setCurrentItem(item);
 
     //now change around in the list
-    printItemList(QLatin1String("itemList before change: "));
+    printItemList(QStringLiteral("itemList before change: "));
     UMLClassifierListItem* currentAtt = getItemList().at(index);
     // NB: The index in the m_pItemListLB is not necessarily the same
     //     as the index in the UMLClassifier::m_List.
@@ -584,7 +565,7 @@ void ClassifierListPage::slotTopClicked()
     logDebug2("ClassifierListPage::slotTopClicked %1: peer index in UMLCanvasItem::m_List is %2",
               currentAtt->name(), index);
     addToClassifier(currentAtt, 0);
-    printItemList(QLatin1String("itemList after change: "));
+    printItemList(QStringLiteral("itemList after change: "));
     slotActivateItem(item);
 }
 
@@ -610,7 +591,7 @@ void ClassifierListPage::slotUpClicked()
     m_pItemListLB->setCurrentItem(item);
 
     //now change around in the list
-    printItemList(QLatin1String("itemList before change: "));
+    printItemList(QStringLiteral("itemList before change: "));
     UMLClassifierListItem* currentAtt = getItemList().at(index);
     // NB: The index in the m_pItemListLB is not necessarily the same
     //     as the index in the UMLClassifier::m_List.
@@ -622,7 +603,7 @@ void ClassifierListPage::slotUpClicked()
     if (index == -1)
         index = 0;
     addToClassifier(currentAtt, index);
-    printItemList(QLatin1String("itemList after change: "));
+    printItemList(QStringLiteral("itemList after change: "));
     slotActivateItem(item);
 }
 
@@ -647,7 +628,7 @@ void ClassifierListPage::slotDownClicked()
     QListWidgetItem* item = m_pItemListLB->item(index + 1);
     m_pItemListLB->setCurrentItem(item);
     //now change around in the list
-    printItemList(QLatin1String("itemList before change: "));
+    printItemList(QStringLiteral("itemList before change: "));
     UMLClassifierListItem* currentAtt = getItemList().at(index);
     // NB: The index in the m_pItemListLB is not necessarily the same
     //     as the index in the UMLClassifier::m_List.
@@ -659,7 +640,7 @@ void ClassifierListPage::slotDownClicked()
     if (index != -1)
         index++;   // because we want to go _after_ the following peer item
     addToClassifier(currentAtt, index);
-    printItemList(QLatin1String("itemList after change: "));
+    printItemList(QStringLiteral("itemList after change: "));
     slotActivateItem(item);
 }
 
@@ -684,7 +665,7 @@ void ClassifierListPage::slotBottomClicked()
     m_pItemListLB->setCurrentItem(item);
 
     //now change around in the list
-    printItemList(QLatin1String("itemList before change: "));
+    printItemList(QStringLiteral("itemList before change: "));
     UMLClassifierListItem* currentAtt = getItemList().at(index);
     // NB: The index in the m_pItemListLB is not necessarily the same
     //     as the index in the UMLClassifier::m_List.
@@ -694,7 +675,7 @@ void ClassifierListPage::slotBottomClicked()
     logDebug2("ClassifierListPage::slotBottomClicked %1: peer index in UMLCanvasItem::m_List is %2",
               currentAtt->name(), index);
     addToClassifier(currentAtt, getItemList().count());
-    printItemList(QLatin1String("itemList after change: "));
+    printItemList(QStringLiteral("itemList after change: "));
     slotActivateItem(item);
 }
 
