@@ -1,34 +1,32 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2014-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2014-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
 #include "import_argo.h"
 
 // app includes
+#define DBG_SRC QStringLiteral("Import_Argo")
 #include "debug_utils.h"
 #include "uml.h"
 #include "umldoc.h"
 
 // kde includes
 #include <KLocalizedString>
-#if QT_VERSION < 0x050000
-#include <KTempDir>
-#endif
 #include <KZip>
 
 // qt includes
 #include <QFile>
 #include <QStringList>
-#if QT_VERSION >= 0x050000
 #include <QTemporaryDir>
-#endif
 #include <QXmlStreamReader>
 
+DEBUG_REGISTER(Import_Argo)
+
 static void reportError(const QXmlStreamReader &xml, const KZip &zipFile, const QString &fileName)
 {
-    uError() << xml.name() << "in file" << zipFile.fileName() << ":" << fileName;
+    logError3("Import_Argo %1 in file %2 : %3", xml.name().toString(), zipFile.fileName(), fileName);
 }
 
 bool Import_Argo::loadFromArgoFile(const KZip &zipFile, const QString &fileName)
@@ -43,18 +41,19 @@ bool Import_Argo::loadFromArgoFile(const KZip &zipFile, const QString &fileName)
     bool result = true;
     while (!xml.atEnd()) {
         xml.readNext();
-        if (xml.name() == QLatin1String("member")) {
+        if (xml.name() == QStringLiteral("member")) {
             QXmlStreamAttributes attributes = xml.attributes();
-            QString type = attributes.value(QLatin1String("type")).toString();
-            QString name = attributes.value(QLatin1String("name")).toString();
-            if (type == QLatin1String("xmi") && !loadFromXMIFile(zipFile, name))
+            QString type = attributes.value(QStringLiteral("type")).toString();
+            QString name = attributes.value(QStringLiteral("name")).toString();
+            if (type == QStringLiteral("xmi") && !loadFromXMIFile(zipFile, name))
                 result = false;
-            else if (type == QLatin1String("pgml") && !loadFromPGMLFile(zipFile, name))
+            else if (type == QStringLiteral("pgml") && !loadFromPGMLFile(zipFile, name))
                 result = false;
-            else if (type == QLatin1String("todo") && loadFromTodoFile(zipFile, name))
+            else if (type == QStringLiteral("todo") && loadFromTodoFile(zipFile, name))
                 result = false;
             else {
-                uError() << "unknown file type" << type << "in file" << zipFile.fileName() << ":" << fileName;
+                logError3("loadFromArgoFile unknown file type %1 in file %2 : %3",
+                          type, zipFile.fileName(), fileName);
                 result = false;
             }
         }
@@ -77,7 +76,8 @@ bool Import_Argo::loadFromPGMLFile(const KZip &zipFile, const QString &fileName)
 
     while (!xml.atEnd()) {
         xml.readNext();
-        uDebug() << "unhandled tag" << xml.name() << "in file" <<  zipFile.fileName() << ":" << fileName;
+        logDebug3("Import_Argo::loadFromPGMLFile unhandled tag %1 in file %2:%3",
+                  xml.name().toString(), zipFile.fileName(), fileName);
     }
     if (xml.hasError()) {
         reportError(xml, zipFile, fileName);
@@ -97,7 +97,8 @@ bool Import_Argo::loadFromTodoFile(const KZip &zipFile, const QString &fileName)
 
     while (!xml.atEnd()) {
         xml.readNext();
-        uDebug() << "unhandled tag" << xml.name() << "in file" << zipFile.fileName() << ":" << fileName;
+        logDebug3("Import_Argo::loadFromTodoFile unhandled tag %1 in file %2:%3",
+                  xml.name().toString(), zipFile.fileName(), fileName);
     }
     if (xml.hasError()) {
         reportError(xml, zipFile, fileName);
@@ -112,24 +113,15 @@ bool Import_Argo::loadFromXMIFile(const KZip &zipFile, const QString &fileName)
     if (!file)
         return false;
 
-#if QT_VERSION >= 0x050000
     QTemporaryDir tmpDir;
-#else
-    KTempDir tmpDir;
-#endif
     tmpDir.setAutoRemove(true);
 
-#if QT_VERSION >= 0x050000
     file->copyTo(tmpDir.path());
     QFile xmiFile(tmpDir.path() + QLatin1Char('/') + file->name());
-#else
-    file->copyTo(tmpDir.name());
-    QFile xmiFile(tmpDir.name() + file->name());
-#endif
     if(!xmiFile.open(QIODevice::ReadOnly)) {
         return false;
     }
-    return UMLApp::app()->document()->loadFromXMI1(xmiFile, 0);
+    return UMLApp::app()->document()->loadFromXMI(xmiFile, 0);
 }
 
 bool Import_Argo::loadFromZArgoFile(QIODevice &file, UMLPackage *parentPkg)
@@ -147,10 +139,10 @@ bool Import_Argo::loadFromZArgoFile(QIODevice &file, UMLPackage *parentPkg)
         if (entry->isFile()) {
             const KArchiveFile *file = static_cast<const KArchiveFile*>(entry);
             if (file == 0) {
-                uError() << "Could not read file from" << file;
+                logError1("loadFromZArgoFile: Could not read file from %1", name);
                 continue;
             }
-            if (name.endsWith(QLatin1String(".argo")))
+            if (name.endsWith(QStringLiteral(".argo")))
                 result = loadFromArgoFile(zipFile, name);
         }
     }
